@@ -33,7 +33,6 @@ import com.ibm.icu.impl.number.DecimalFormatProperties;
 import com.ibm.icu.impl.number.PatternStringParser;
 import com.ibm.icu.text.CompactDecimalFormat;
 import com.ibm.icu.text.CompactDecimalFormat.CompactStyle;
-import com.ibm.icu.text.DecimalFormat;
 import com.ibm.icu.text.DecimalFormat.PropertySetter;
 import com.ibm.icu.text.NumberFormat;
 import com.ibm.icu.util.Currency;
@@ -464,6 +463,7 @@ public class CompactDecimalFormatTest extends CoreTestFmwk {
     }
 
     @Test
+    @SuppressWarnings("JdkObsolete") // Because of CompactDecimalFormat.format(..., StringBuffer)
     public void TestFieldPosition() {
         CompactDecimalFormat cdf = getCDFInstance(
                 ULocale.forLanguageTag("sw"), CompactStyle.SHORT);
@@ -704,11 +704,14 @@ public class CompactDecimalFormatTest extends CoreTestFmwk {
         assertEquals("CDF should correctly format 1234 with 3 significant digits in 'ar-EG'", "١٫٢٣ ألف", result);
 
         // Check currency formatting as well
-        cdf = CompactDecimalFormat.getInstance(new ULocale("ar-EG"), CompactDecimalFormat.CompactStyle.SHORT);
-        result = cdf.format(new CurrencyAmount(43000f, Currency.getInstance("USD")));
-        assertEquals("CDF should correctly format 43000 with currency in 'ar-EG'", "٤٣ ألف US$", result);
-        result = cdf.format(new CurrencyAmount(-43000f, Currency.getInstance("USD")));
-        assertEquals("CDF should correctly format -43000 with currency in 'ar-EG'", "؜-٤٣ ألف US$", result);
+        if (!logKnownIssue("ICU-23188", "Compact number formatting for ar-EG adds extra RLM")) {
+            cdf = CompactDecimalFormat.getInstance(new ULocale("ar-EG"), CompactDecimalFormat.CompactStyle.SHORT);
+            result = cdf.format(new CurrencyAmount(43000f, Currency.getInstance("USD")));  
+            assertEquals("CDF should correctly format 43000 with currency in 'ar-EG'", "٤٣ ألف US$", result);
+            result = cdf.format(new CurrencyAmount(-43000f, Currency.getInstance("USD")));
+            assertEquals("CDF should correctly format -43000 with currency in 'ar-EG'", "؜-٤٣ ألف US$", result);
+        }	
+
 
         // Extra locale with different positive/negative formats
         cdf = CompactDecimalFormat.getInstance(new ULocale("fi"), CompactDecimalFormat.CompactStyle.SHORT);
@@ -740,7 +743,7 @@ public class CompactDecimalFormatTest extends CoreTestFmwk {
 
         cdf = CompactDecimalFormat.getInstance(ULocale.forLanguageTag("it"), CompactStyle.SHORT);
         result = cdf.format(new CurrencyAmount(123000, Currency.getInstance("EUR")));
-        assertEquals("CDF should correctly format 123000 with currency in 'it'", "123.000\u00A0€", result);
+        assertEquals("CDF should correctly format 123000 with currency in 'it'", "123K\u00A0€", result);
     }
 
     @Test
@@ -752,13 +755,14 @@ public class CompactDecimalFormatTest extends CoreTestFmwk {
 
     @Test
     public void TestBug12975() {
-        ULocale locale = new ULocale("it");
-        CompactDecimalFormat cdf = CompactDecimalFormat.getInstance(locale, CompactStyle.SHORT);
-        String resultCdf = cdf.format(12000);
-        DecimalFormat df = (DecimalFormat) DecimalFormat.getInstance(locale);
-        String resultDefault = df.format(12000);
-        assertEquals("CompactDecimalFormat should use default pattern when compact pattern is unavailable",
-                     resultDefault, resultCdf);
+    	// ** This test is no  longer valid as of CLDR 48, `it` now has full compact currency forms
+        //ULocale locale = new ULocale("it");
+        //CompactDecimalFormat cdf = CompactDecimalFormat.getInstance(locale, CompactStyle.SHORT);
+        //String resultCdf = cdf.format(12000);
+        //DecimalFormat df = (DecimalFormat) DecimalFormat.getInstance(locale);
+        //String resultDefault = df.format(12000);
+        //assertEquals("CompactDecimalFormat should use default pattern when compact pattern is unavailable",
+        //             resultDefault, resultCdf);
     }
 
     @Test
