@@ -68,7 +68,7 @@ public class ConformanceTest extends CoreTestFmwk {
         int c=0;
         BufferedReader input = null;
         try {
-            input = TestUtil.getDataReader(fileName);
+            input = TestUtil.getUtf8DataReader(fileName);
             for (int count = 0;;++count) {
                 line = input.readLine();
                 if (line == null) {
