@@ -24,6 +24,7 @@ import org.junit.Test;
 import org.junit.runner.RunWith;
 
 import com.ibm.icu.dev.test.CoreTestFmwk;
+import com.ibm.icu.impl.ICUDebug;
 import com.ibm.icu.impl.locale.LikelySubtags;
 import com.ibm.icu.impl.locale.XCldrStub.FileUtilities;
 import com.ibm.icu.util.LocaleMatcher;
@@ -41,6 +42,7 @@ import junitparams.Parameters;
  */
 @RunWith(JUnitParamsRunner.class)
 public class LocaleMatcherTest extends CoreTestFmwk {
+    private static final boolean DEBUG = ICUDebug.enabled("localematchertest");
     private static final ULocale ZH_MO = new ULocale("zh_MO");
     private static final ULocale ZH_HK = new ULocale("zh_HK");
 
@@ -824,11 +826,17 @@ public class LocaleMatcherTest extends CoreTestFmwk {
             timeLocaleMatcher(desired, matcherLong, WARM_UP_ITERATIONS);
             timeLocaleMatcher(desired, matcherVeryLong, WARM_UP_ITERATIONS);
             long tns = timeLocaleMatcher(desired, matcherShort, BENCHMARK_ITERATIONS);
-            System.out.format("New Duration (few  supported):\t%s\t%d\tnanos\n", desired, tns);
+            if (DEBUG) {
+                System.out.format("New Duration (few  supported):\t%s\t%d\tnanos\n", desired, tns);
+            }
             long tnl = timeLocaleMatcher(desired, matcherLong, BENCHMARK_ITERATIONS);
-            System.out.format("New Duration (med. supported):\t%s\t%d\tnanos\n", desired, tnl);
+            if (DEBUG) {
+                System.out.format("New Duration (med. supported):\t%s\t%d\tnanos\n", desired, tnl);
+            }
             long tnv = timeLocaleMatcher(desired, matcherVeryLong, BENCHMARK_ITERATIONS);
-            System.out.format("New Duration (many supported):\t%s\t%d\tnanos\n", desired, tnv);
+            if (DEBUG) {
+                System.out.format("New Duration (many supported):\t%s\t%d\tnanos\n", desired, tnv);
+            }
         }
 
         maximizePerf();
@@ -859,8 +867,10 @@ public class LocaleMatcherTest extends CoreTestFmwk {
         t = timeMaximize(list, iterations);
         int length = 0;
         for (@SuppressWarnings("unused") ULocale locale : list) { ++length; }
-        System.out.println("maximize: " + (t / iterations / length) + " ns/locale: " +
-                t + " ns / " + iterations + " iterations / " + length + " locales");
+        if (DEBUG) {
+            System.out.println("maximize: " + (t / iterations / length) + " ns/locale: " +
+                    t + " ns / " + iterations + " iterations / " + length + " locales");
+        }
     }
 
     // returns total ns not per iteration
@@ -1007,7 +1017,7 @@ public class LocaleMatcherTest extends CoreTestFmwk {
                         Integer prevIndex = uniqueTests.get(inputs);
                         if (prevIndex == null) {
                             uniqueTests.put(inputs, tests.size());
-                        } else {
+                        } else if (DEBUG) {
                             System.out.println("Locale matcher test case on line " + test.lineNr
                                     + " is a duplicate of line " + tests.get(prevIndex).lineNr);
                         }
@@ -1019,7 +1029,9 @@ public class LocaleMatcherTest extends CoreTestFmwk {
                 }
             }
         }
-        System.out.println("Number of duplicate locale matcher test cases: " + (tests.size() - uniqueTests.size()));
+        if (DEBUG) {
+            System.out.println("Number of duplicate locale matcher test cases: " + (tests.size() - uniqueTests.size()));
+        }
         return tests;
     }
 
